@@ -102,6 +102,24 @@ namespace stan {
        */
       bool operator()(const integrate_ode_control& e) const;
 
+      /**
+       * Return true if the specified expression contains a variable
+       * not declared as a parameter.
+       *
+       * @param[in] e expression
+       * @return true if contains a variable not declared as a parameter
+       */
+       bool operator()(const algebra_solver& e) const;
+
+      /**
+       * Return true if the specified expression contains a variable
+       * not declared as a parameter.
+       *
+       * @param[in] e expression
+       * @return true if contains a variable not declared as a parameter
+       */
+       bool operator()(const algebra_solver_control& e) const;
+
       /**
        * Return true if the specified expression contains a variable
        * not declared as a parameter.
