@@ -69,6 +69,16 @@ namespace stan {
         || boost::apply_visitor(*this, e.theta_.expr_);
     }
 
+    bool has_var_vis::operator()(const algebra_solver& e) const {
+      // only theta may contain vars
+      return boost::apply_visitor(*this, e.theta_.expr_);
+    }
+
+    bool has_var_vis::operator()(const algebra_solver_control& e) const {
+      // only theta may contain vars
+      return boost::apply_visitor(*this, e.theta_.expr_);
+    }
+
     bool has_var_vis::operator()(const index_op& e) const {
       return boost::apply_visitor(*this, e.expr_.expr_);
     }
