@@ -17,6 +17,8 @@ namespace stan {
     struct fun;
     struct integrate_ode;
     struct integrate_ode_control;
+    struct algebra_solver;
+    struct algebra_solver_control;
     struct index_op;
     struct index_op_sliced;
     struct conditional_op;
@@ -125,6 +127,24 @@ namespace stan {
        */
       bool operator()(const integrate_ode_control& e) const;
 
+      /**
+       * Return true if the variable occurs in the specified
+       * expression.
+       *
+       * @param[in] e expression
+       * @return true if the variable occurs in the arguments
+       */
+      bool operator()(const algebra_solver& e) const;
+
+      /**
+       * Return true if the variable occurs in the specified
+       * expression.
+       *
+       * @param[in] e expression
+       * @return true if the variable occurs in the arguments
+       */
+      bool operator()(const algebra_solver_control& e) const;
+
       /**
        * Return true if the variable occurs in the specified
        * expression.
