@@ -20,6 +20,8 @@ namespace stan {
     struct fun;
     struct integrate_ode;
     struct integrate_ode_control;
+    struct algebra_solver;
+    struct algebra_solver_control;
     struct index_op;
     struct index_op_sliced;
     struct conditional_op;
@@ -36,6 +38,8 @@ namespace stan {
                              boost::recursive_wrapper<variable>,
                              boost::recursive_wrapper<integrate_ode>,
                              boost::recursive_wrapper<integrate_ode_control>,
+                             boost::recursive_wrapper<algebra_solver>,
+                             boost::recursive_wrapper<algebra_solver_control>,
                              boost::recursive_wrapper<fun>,
                              boost::recursive_wrapper<index_op>,
                              boost::recursive_wrapper<index_op_sliced>,
@@ -58,6 +62,8 @@ namespace stan {
       expression(const fun& expr);  // NOLINT(runtime/explicit)
       expression(const integrate_ode& expr);  // NOLINT(runtime/explicit)
       expression(const integrate_ode_control& expr);  // NOLINT
+      expression(const algebra_solver& expr);  // NOLINT(runtime/explicit)
+      expression(const algebra_solver_control& expr);  // NOLINT
       expression(const index_op& expr);  // NOLINT(runtime/explicit)
       expression(const index_op_sliced& expr);  // NOLINT(runtime/explicit)
       expression(const conditional_op& expr);  // NOLINT(runtime/explicit)
