@@ -43,6 +43,16 @@ namespace stan {
       return expr_type(DOUBLE_T, 2);
     }
 
+    expr_type
+    expression_type_vis::operator()(const algebra_solver& e) const {
+      return expr_type(VECTOR_T, 0);
+    }
+
+    expr_type
+    expression_type_vis::operator()(const algebra_solver_control& e) const {
+      return expr_type(VECTOR_T, 0);
+    }
+
     expr_type expression_type_vis::operator()(const fun& e) const {
       return e.type_;
     }
