@@ -4,10 +4,12 @@
 #include <stan/io/program_reader.hpp>
 #include <stan/lang/ast.hpp>
 #include <stan/lang/generator/constants.hpp>
+#include <stan/lang/generator/generate_catch_throw_located.hpp>
 #include <stan/lang/generator/generate_comment.hpp>
-#include <stan/lang/generator/generate_located_statements.hpp>
 #include <stan/lang/generator/generate_member_var_inits.hpp>
 #include <stan/lang/generator/generate_set_param_ranges.hpp>
+#include <stan/lang/generator/generate_statements.hpp>
+#include <stan/lang/generator/generate_try.hpp>
 #include <stan/lang/generator/generate_validate_var_decls.hpp>
 #include <stan/lang/generator/generate_var_resizing.hpp>
 #include <stan/lang/generator/generate_void_statement.hpp>
@@ -64,28 +66,29 @@ namespace stan {
       o << INDENT2 << "(void) DUMMY_VAR__;  // suppress unused var warning"
         << EOL2;
       o << INDENT2 << "// initialize member variables" << EOL;
-      generate_member_var_inits(prog.data_decl_, o);
+      generate_try(2, o);
+      generate_member_var_inits(prog.data_decl_, 3, o);
       o << EOL;
-      generate_comment("validate, data variables", 2, o);
-      generate_validate_var_decls(prog.data_decl_, 2, o);
-      generate_comment("initialize data variables", 2, o);
-      generate_var_resizing(prog.derived_data_decl_.first, o);
+      generate_comment("validate, data variables", 3, o);
+      generate_validate_var_decls(prog.data_decl_, 3, o);
+      generate_comment("initialize data variables", 3, o);
+      generate_var_resizing(prog.derived_data_decl_.first, 3, o);
       o << EOL;
 
       bool include_sampling = false;
       bool is_var_context = false;
       bool is_fun_return = false;
 
-      // need to fix generate_located_statements
-      generate_located_statements(prog.derived_data_decl_.second,
-                                  2, o, include_sampling, is_var_context,
-                                  is_fun_return);
+      generate_statements(prog.derived_data_decl_.second,
+                           3, o, include_sampling, is_var_context,
+                           is_fun_return);
       o << EOL;
-      generate_comment("validate transformed data", 2, o);
-      generate_validate_var_decls(prog.derived_data_decl_.first, 2, o);
+      generate_comment("validate transformed data", 3, o);
+      generate_validate_var_decls(prog.derived_data_decl_.first, 3, o);
       o << EOL;
-      generate_comment("validate, set parameter ranges", 2, o);
-      generate_set_param_ranges(prog.parameter_decl_, o);
+      generate_comment("validate, set parameter ranges", 3, o);
+      generate_set_param_ranges(prog.parameter_decl_, 3, o);
+      generate_catch_throw_located(2, o);
       o << INDENT << "}" << EOL;
     }
 
