@@ -15,9 +15,8 @@ namespace stan {
     qr_R(const Eigen::Matrix<fvar<T>, Eigen::Dynamic, Eigen::Dynamic>& m) {
       typedef Eigen::Matrix<fvar<T>, Eigen::Dynamic, Eigen::Dynamic>
         matrix_fwd_t;
-      stan::math::check_nonzero_size("qr_R", "m", m);
-      stan::math::check_greater_or_equal("qr_R", "m.rows()", m.rows(),
-                                         m.cols());
+      check_nonzero_size("qr_R", "m", m);
+      check_greater_or_equal("qr_R", "m.rows()", m.rows(), m.cols());
       Eigen::HouseholderQR< matrix_fwd_t > qr(m.rows(), m.cols());
       qr.compute(m);
       matrix_fwd_t R = qr.matrixQR().topLeftCorner(m.rows(), m.cols());
@@ -29,6 +28,7 @@ namespace stan {
       }
       return R;
     }
+
   }
 }
 #endif
