@@ -7,7 +7,6 @@
 #include <vector>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -33,6 +32,6 @@ namespace stan {
       dfx_dx = fx_fvar.d_;
     }
 
-  }  // namespace math
-}  // namespace stan
+  }
+}
 #endif
