@@ -3,7 +3,6 @@
 
 #include <stan/math/prim/scal/err/out_of_range.hpp>
 #include <stan/math/prim/mat/fun/Eigen.hpp>
-
 #include <sstream>
 #include <string>
 
@@ -11,7 +10,7 @@ namespace stan {
   namespace math {
 
     /**
-     * Return <code>true</code> if the specified index is a valid row of the matrix
+     * Check if the specified index is a valid row of the matrix
      *
      * This check is 1-indexed by default. This behavior can be changed
      * by setting <code>stan::error_index::value</code>.
@@ -25,26 +24,21 @@ namespace stan {
      * @param y Matrix to test
      * @param i is index
      *
-     * @return <code>true</code> if the index is a valid row index in the matrix
      * @throw <code>std::out_of_range</code> if the index is out of range.
      */
     template <typename T_y, int R, int C>
-    inline bool check_row_index(const char* function,
+    inline void check_row_index(const char* function,
                                 const char* name,
                                 const Eigen::Matrix<T_y, R, C>& y,
                                 size_t i) {
       if (i >= stan::error_index::value
           && i < static_cast<size_t>(y.rows()) + stan::error_index::value)
-        return true;
+        return;
 
       std::stringstream msg;
       msg << " for rows of " << name;
       std::string msg_str(msg.str());
-      out_of_range(function,
-                   y.rows(),
-                   i,
-                   msg_str.c_str());
-      return false;
+      out_of_range(function, y.rows(), i, msg_str.c_str());
     }
 
   }
