@@ -7,7 +7,6 @@
 #include <stdexcept>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -24,30 +23,24 @@ namespace stan {
     cholesky_factor_free(const Eigen::Matrix
                          <T, Eigen::Dynamic, Eigen::Dynamic>& y) {
       using std::log;
-      if (!stan::math::check_cholesky_factor("cholesky_factor_free", "y", y))
-        throw std::domain_error("cholesky_factor_free: "
-                                "y is not a Cholesky factor");
+      check_cholesky_factor("cholesky_factor_free", "y", y);
       int M = y.rows();
       int N = y.cols();
       Eigen::Matrix<T, Eigen::Dynamic, 1> x((N * (N + 1)) / 2 + (M - N) * N);
       int pos = 0;
-      // lower triangle of upper square
+
       for (int m = 0; m < N; ++m) {
         for (int n = 0; n < m; ++n)
           x(pos++) = y(m, n);
-        // diagonal of upper square
         x(pos++) = log(y(m, m));
       }
-      // lower rectangle
+
       for (int m = N; m < M; ++m)
         for (int n = 0; n < N; ++n)
           x(pos++) = y(m, n);
       return x;
     }
 
-
   }
-
 }
-
 #endif
