@@ -1,17 +1,16 @@
 #ifndef STAN_MATH_PRIM_MAT_FUN_CORR_MATRIX_FREE_HPP
 #define STAN_MATH_PRIM_MAT_FUN_CORR_MATRIX_FREE_HPP
 
+#include <stan/math/prim/arr/err/check_nonzero_size.hpp>
 #include <stan/math/prim/mat/fun/Eigen.hpp>
-#include <stan/math/prim/mat/meta/index_type.hpp>
 #include <stan/math/prim/mat/err/constraint_tolerance.hpp>
+#include <stan/math/prim/mat/err/check_square.hpp>
+#include <stan/math/prim/scal/err/domain_error.hpp>
 #include <stan/math/prim/mat/fun/factor_cov_matrix.hpp>
-#include <boost/throw_exception.hpp>
+#include <stan/math/prim/mat/meta/index_type.hpp>
 #include <cmath>
-#include <sstream>
-#include <stdexcept>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -38,36 +37,28 @@ namespace stan {
     Eigen::Matrix<T, Eigen::Dynamic, 1>
     corr_matrix_free(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>&
                      y) {
+      check_square("corr_matrix_free", "y", y);
+      check_nonzero_size("corr_matrix_free", "y", y);
+
       using Eigen::Array;
       using Eigen::Dynamic;
       using Eigen::Matrix;
-      using stan::math::index_type;
       typedef typename index_type<Matrix<T, Dynamic, 1> >::type size_type;
 
       size_type k = y.rows();
-      if (y.cols() != k)
-        throw std::domain_error("y is not a square matrix");
-      if (k == 0)
-        throw std::domain_error("y has no elements");
-      size_type k_choose_2 = (k * (k-1)) / 2;
+      size_type k_choose_2 = (k * (k - 1)) / 2;
       Array<T, Dynamic, 1> x(k_choose_2);
       Array<T, Dynamic, 1> sds(k);
       bool successful = factor_cov_matrix(y, x, sds);
       if (!successful)
-        throw std::runtime_error("factor_cov_matrix failed on y");
+        domain_error("corr_matrix_free",
+                     "factor_cov_matrix failed on y", y, "");
       for (size_type i = 0; i < k; ++i) {
-        // sds on log scale unconstrained
-        if (fabs(sds[i] - 0.0) >= CONSTRAINT_TOLERANCE) {
-          std::stringstream s;
-          s << "all standard deviations must be zero."
-            << " found log(sd[" << i << "])=" << sds[i] << std::endl;
-          BOOST_THROW_EXCEPTION(std::runtime_error(s.str()));
-        }
+        check_bounded("corr_matrix_free", "log(sd)",
+                      sds[i], -CONSTRAINT_TOLERANCE, CONSTRAINT_TOLERANCE);
       }
       return x.matrix();
     }
   }
-
 }
-
 #endif
