@@ -1,9 +1,10 @@
 #ifndef STAN_MATH_PRIM_MAT_FUN_DIAG_POST_MULTIPLY_HPP
 #define STAN_MATH_PRIM_MAT_FUN_DIAG_POST_MULTIPLY_HPP
 
+#include <stan/math/prim/mat/err/check_vector.hpp>
+#include <stan/math/prim/scal/err/check_size_match.hpp>
 #include <stan/math/prim/mat/fun/Eigen.hpp>
 #include <boost/math/tools/promotion.hpp>
-#include <stdexcept>
 
 namespace stan {
   namespace math {
@@ -13,11 +14,11 @@ namespace stan {
                   R1, C1>
     diag_post_multiply(const Eigen::Matrix<T1, R1, C1>& m1,
                   const Eigen::Matrix<T2, R2, C2>& m2) {
-      if (m2.cols() != 1 && m2.rows() != 1)
-        throw std::domain_error("m2 must be a vector");
+      check_vector("diag_post_multiply", "m2", m2);
       int m1_cols = m1.cols();
-      if (m2.size() != m1_cols)
-        throw std::domain_error("m2 must have same length as m1 has columns");
+      check_size_match("diag_post_multiply",
+                       "m2.size()", m2.size(),
+                       "m1.cols()", m1_cols);
       int m1_rows = m1.rows();
       Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type,
                     R1, C1>
