@@ -52,8 +52,7 @@ namespace stan {
                                                   T_scale_fail>::type
         T_partials_return;
 
-      if (!(stan::length(y) && stan::length(alpha)
-            && stan::length(beta)))
+      if (!(stan::length(y) && stan::length(alpha) && stan::length(beta)))
         return 1.0;
 
       static const char* function("beta_cdf");
