@@ -30,10 +30,8 @@ namespace stan {
         typename stan::partials_return_type<T_y, T_loc, T_scale, T_shape>::type
         T_partials_return;
 
-      if ( !( stan::length(y)
-              && stan::length(mu)
-              && stan::length(lambda)
-              && stan::length(alpha) ) )
+      if (!(stan::length(y) && stan::length(mu) && stan::length(lambda)
+            && stan::length(alpha)))
         return 1.0;
 
       static const char* function("pareto_type_2_cdf");
