@@ -48,9 +48,7 @@ namespace stan {
       using boost::math::tools::promote_args;
       using std::log;
 
-      if (!(stan::length(y)
-            && stan::length(alpha)
-            && stan::length(sigma)))
+      if (!(stan::length(y) && stan::length(alpha) && stan::length(sigma)))
         return 0.0;
 
       T_partials_return ccdf_log(0.0);
