@@ -50,7 +50,8 @@ namespace stan {
      */
     inline var variance(const std::vector<var>& v) {
       check_nonzero_size("variance", "v", v);
-      if (v.size() == 1) return 0;
+      if (v.size() == 1)
+        return 0;
       return calc_variance(v.size(), &v[0]);
     }
 
@@ -67,7 +68,8 @@ namespace stan {
     template <int R, int C>
     var variance(const Eigen::Matrix<var, R, C>& m) {
       check_nonzero_size("variance", "m", m);
-      if (m.size() == 1) return 0;
+      if (m.size() == 1)
+        return 0;
       return calc_variance(m.size(), &m(0));
     }
 
