@@ -267,7 +267,28 @@ long int N_VGetLength_Serial(N_Vector v)
  
 void N_VPrint_Serial(N_Vector x)
 {
-  // Deleted to avoid warning from R CMD check
+#ifndef NO_FPRINTF_OUTPUT
+  long int i, N;
+  realtype *xd;
+
+  xd = NULL;
+
+  N  = NV_LENGTH_S(x);
+  xd = NV_DATA_S(x);
+
+  for (i = 0; i < N; i++) {
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+    printf("%35.32Lg\n", xd[i]);
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
+    printf("%19.16g\n", xd[i]);
+#else
+    printf("%11.8g\n", xd[i]);
+#endif
+  }
+  printf("\n");
+#endif
+
+  return;
 }
 
 /*
